@@ -1,54 +1,32 @@
 # -*- coding: utf-8 -*-
 """
 # Crypto SQL
-# Copyright (c) 2011-2022 Michael Buesch <m@bues.ch>
+# Copyright (c) 2011-2023 Michael Büsch <m@bues.ch>
 # Licensed under the GNU/GPL version 2 or later.
 """
 
 import functools
 import hashlib
-import os
 import re
 import secrets
 import sqlite3 as sql
-import sys
 import zlib
 
 from libpwman.fileobj import *
-
-def missingMod(name, debpack=None, pip=None):
-	print("ERROR: The Python '%s' module is not installed." % name, file=sys.stderr)
-	if debpack:
-		print("Debian:  apt install %s" % debpack, file=sys.stderr)
-	if pip:
-		print("PyPi:  pip3 install %s" % pip, file=sys.stderr)
-	sys.exit(1)
-
-try:
-	import pyaes
-except ImportError as e:
-	missingMod("pyaes", "python3-pyaes", "pyaes")
-
+from libpwman.aes import AES
 
 __all__ = [
 	"CSQLError",
 	"CryptSQL",
 ]
 
-
 CSQL_HEADER = b"CryptSQL v1"
 
-
 class CSQLError(Exception):
 	"""CryptSQL exception.
 	"""
 
-class CompressDummy(object):
-	def compress(self, payload, *args):
-		return payload
-	decompress = compress
-
-class CryptSQLCursor(object):
+class CryptSQLCursor:
 	"""Encrypted SQL database cursor.
 	"""
 
@@ -104,7 +82,7 @@ class CryptSQLCursor(object):
 		except (sql.Error, sql.DatabaseError) as e:
 			raise CSQLError("Database error: " + str(e))
 
-class CryptSQL(object):
+class CryptSQL:
 	"""Encrypted SQL database.
 	"""
 
@@ -175,7 +153,7 @@ class CryptSQL(object):
 			kdfIter = fc.getOne(b"KDF_ITER", "Invalid KDF_ITER object")
 			kdfHash = fc.getOne(b"KDF_HASH", "Invalid KDF_HASH object")
 			kdfMac = fc.getOne(b"KDF_MAC", "Invalid KDF_MAC object")
-			compress = fc.getOne(b"COMPRESS", "Invalid COMPRESS object")
+			compress = fc.getOne(b"COMPRESS", default=b"NONE")
 			paddingMethod = fc.getOne(b"PADDING", default=b"PWMAN")
 			payload = fc.getOne(b"PAYLOAD", "Invalid PAYLOAD object")
 
@@ -186,21 +164,14 @@ class CryptSQL(object):
 
 			# Check the cipher.
 			if cipher == b"AES" and cipherMode == b"CBC":
-				if paddingMethod == b"PKCS7":
-					decrypter = lambda c: pyaes.Decrypter(c,\
-							padding=pyaes.PADDING_DEFAULT)
-				else:
-					decrypter = lambda c: pyaes.Decrypter(c,\
-							padding=pyaes.PADDING_NONE)
-				cipher = pyaes.AESModeOfOperationCBC
-				cipherBlockSize = 128 // 8
+				cipherBlockSize = AES.BLOCK_SIZE
 			else:
 				raise CSQLError("Unknown cipher/mode: %s/%s" % (
 					cipher.decode("UTF-8", "ignore"),
 					cipherMode.decode("UTF-8", "ignore")))
 
 			# Check the cipher IV.
-			if not cipherIV:
+			if not cipherIV: # legacy
 				cipherIV = b'\x00' * cipherBlockSize
 			if len(cipherIV) != cipherBlockSize:
 				raise CSQLError("Invalid IV len: %d" % len(cipherIV))
@@ -238,10 +209,13 @@ class CryptSQL(object):
 				raise CSQLError("Unknown kdf method: %s" % kdfMethod)
 
 			# Check the compression method.
-			if compress == b"ZLIB":
+			if compress == b"NONE":
+				class DecompressDummy:
+					def decompress(self, payload):
+						return payload
+				compress = DecompressDummy()
+			elif compress == b"ZLIB": # legacy
 				compress = zlib
-			elif compress == b"NONE":
-				compress = CompressDummy()
 			else:
 				raise CSQLError("Unknown compression: %s" % compress)
 
@@ -253,13 +227,13 @@ class CryptSQL(object):
 
 			try:
 				# Decrypt payload.
-				dec = decrypter(cipher(key=key, iv=cipherIV))
-				payload = dec.feed(payload)
-				payload += dec.feed()
-				if paddingMethod == b"PWMAN":
-					payload = self.__unpad_PWMAN(payload)
+				payload = AES.get().decrypt(
+					key=key,
+					iv=cipherIV,
+					data=payload,
+					legacyPadding=(paddingMethod == b"PWMAN"))
 
-				# Decompress payload.
+				# Decompress payload (legacy).
 				payload = compress.decompress(payload)
 
 				# Import the SQL database.
@@ -305,15 +279,6 @@ class CryptSQL(object):
 		self.__filename = None
 		self.__passphrase = None
 
-	@staticmethod
-	def __unpad_PWMAN(data):
-		"""Strip legacy padding.
-		"""
-		index = data.rfind(b"\xFF")
-		if index < 0 or index >= len(data):
-			raise CSQLError("unpad_PWMAN: error")
-		return data[:index]
-
 	def __random(self, nrBytes):
 		"""Return cryptographically secure random bytes.
 		nrBytes: The number of bytes to return.
@@ -372,13 +337,8 @@ class CryptSQL(object):
 						  dklen=keyLen)
 
 			# Encrypt payload
-			cipherBlockSize = 128 // 8
-			cipherIV = self.__random(cipherBlockSize)
-			enc = pyaes.Encrypter(pyaes.AESModeOfOperationCBC(key=key,
-									  iv=cipherIV),
-					      padding=pyaes.PADDING_DEFAULT)
-			payload = enc.feed(payload)
-			payload += enc.feed()
+			cipherIV = self.__random(AES.BLOCK_SIZE)
+			payload = AES.get().encrypt(key=key, iv=cipherIV, data=payload)
 		except Exception as e:
 			raise CSQLError("Failed to encrypt: %s" % str(e))
 
@@ -395,7 +355,7 @@ class CryptSQL(object):
 				FileObj(b"KDF_ITER", str(kdfIter).encode("UTF-8")),
 				FileObj(b"KDF_HASH", kdfHash.encode("UTF-8")),
 				FileObj(b"KDF_MAC", b"HMAC"),
-				FileObj(b"COMPRESS", b"NONE"),
+				FileObj(b"COMPRESS", b"NONE"), # compat for older versions.
 				FileObj(b"PADDING", b"PKCS7"),
 				FileObj(b"PAYLOAD", payload),
 			)
