@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """
 # Simple password manager
-# Copyright (c) 2011-2021 Michael Buesch <m@bues.ch>
+# Copyright (c) 2011-2023 Michael Büsch <m@bues.ch>
 # Licensed under the GNU/GPL version 2 or later.
 """
 
@@ -1261,7 +1261,7 @@ class PWMan(Cmd, metaclass=PWManMeta):
 				       ignoreFirst=True, unescape=unescape)
 
 	@dataclass
-	class Opts(object):
+	class Opts:
 		__opts : list = field(default_factory=list)
 		__params : list = field(default_factory=list)
 		__atCmdIndex : dict = field(default_factory=dict)
